## CChecksum

CChecksum is a ~2x faster drop-in replacement for eth_utils.to_checksum_address, with the most cpu-intensive part implemented in c.

Just pip install it, drop it in, and run your script with a substantial speed improvement.
